# pulpcore_client

PulpcoreClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 3.7.1
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulpcore_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulpcore_client-3.7.1.gem
```

(for development, run `gem install --dev ./pulpcore_client-3.7.1.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulpcore_client', '~> 3.7.1'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulpcore_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulpcore_client'

# Setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List access policys
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->list: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpcoreClient::AccessPoliciesApi* | [**list**](docs/AccessPoliciesApi.md#list) | **GET** /pulp/api/v3/access_policies/ | List access policys
*PulpcoreClient::AccessPoliciesApi* | [**partial_update**](docs/AccessPoliciesApi.md#partial_update) | **PATCH** {access_policy_href} | Update an access policy
*PulpcoreClient::AccessPoliciesApi* | [**read**](docs/AccessPoliciesApi.md#read) | **GET** {access_policy_href} | Inspect an access policy
*PulpcoreClient::AccessPoliciesApi* | [**update**](docs/AccessPoliciesApi.md#update) | **PUT** {access_policy_href} | Update an access policy
*PulpcoreClient::ArtifactsApi* | [**create**](docs/ArtifactsApi.md#create) | **POST** /pulp/api/v3/artifacts/ | Create an artifact
*PulpcoreClient::ArtifactsApi* | [**delete**](docs/ArtifactsApi.md#delete) | **DELETE** {artifact_href} | Delete an artifact
*PulpcoreClient::ArtifactsApi* | [**list**](docs/ArtifactsApi.md#list) | **GET** /pulp/api/v3/artifacts/ | List artifacts
*PulpcoreClient::ArtifactsApi* | [**read**](docs/ArtifactsApi.md#read) | **GET** {artifact_href} | Inspect an artifact
*PulpcoreClient::ExportersCoreExportsApi* | [**create**](docs/ExportersCoreExportsApi.md#create) | **POST** {core_pulp_pulp_export_href}exports/ | Create a pulp export
*PulpcoreClient::ExportersCoreExportsApi* | [**delete**](docs/ExportersCoreExportsApi.md#delete) | **DELETE** {core_pulp_pulp_export_href} | Delete a pulp export
*PulpcoreClient::ExportersCoreExportsApi* | [**list**](docs/ExportersCoreExportsApi.md#list) | **GET** {pulp_exporter_href}exports/ | List pulp exports
*PulpcoreClient::ExportersCoreExportsApi* | [**read**](docs/ExportersCoreExportsApi.md#read) | **GET** {core_pulp_pulp_export_href} | Inspect a pulp export
*PulpcoreClient::ExportersPulpApi* | [**create**](docs/ExportersPulpApi.md#create) | **POST** /pulp/api/v3/exporters/core/pulp/ | Create a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**delete**](docs/ExportersPulpApi.md#delete) | **DELETE** {pulp_exporter_href} | Delete a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**list**](docs/ExportersPulpApi.md#list) | **GET** /pulp/api/v3/exporters/core/pulp/ | List pulp exporters
*PulpcoreClient::ExportersPulpApi* | [**partial_update**](docs/ExportersPulpApi.md#partial_update) | **PATCH** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**read**](docs/ExportersPulpApi.md#read) | **GET** {pulp_exporter_href} | Inspect a pulp exporter
*PulpcoreClient::ExportersPulpApi* | [**update**](docs/ExportersPulpApi.md#update) | **PUT** {pulp_exporter_href} | Update a pulp exporter
*PulpcoreClient::GroupsApi* | [**create**](docs/GroupsApi.md#create) | **POST** /pulp/api/v3/groups/ | Create a group
*PulpcoreClient::GroupsApi* | [**delete**](docs/GroupsApi.md#delete) | **DELETE** {auth_group_href} | Delete a group
*PulpcoreClient::GroupsApi* | [**list**](docs/GroupsApi.md#list) | **GET** /pulp/api/v3/groups/ | List groups
*PulpcoreClient::GroupsApi* | [**partial_update**](docs/GroupsApi.md#partial_update) | **PATCH** {auth_group_href} | Update a group
*PulpcoreClient::GroupsApi* | [**read**](docs/GroupsApi.md#read) | **GET** {auth_group_href} | Inspect a group
*PulpcoreClient::GroupsApi* | [**update**](docs/GroupsApi.md#update) | **PUT** {auth_group_href} | Update a group
*PulpcoreClient::GroupsModelPermissionsApi* | [**create**](docs/GroupsModelPermissionsApi.md#create) | **POST** {auth_auth_groups_permission_href}model_permissions/ | Create a permission
*PulpcoreClient::GroupsModelPermissionsApi* | [**list**](docs/GroupsModelPermissionsApi.md#list) | **GET** {auth_group_href}model_permissions/ | List permissions
*PulpcoreClient::GroupsObjectPermissionsApi* | [**create**](docs/GroupsObjectPermissionsApi.md#create) | **POST** {auth_auth_groups_permission_href}object_permissions/ | Create a permission
*PulpcoreClient::GroupsObjectPermissionsApi* | [**delete**](docs/GroupsObjectPermissionsApi.md#delete) | **DELETE** {auth_auth_groups_permission_href} | Delete a permission
*PulpcoreClient::GroupsObjectPermissionsApi* | [**list**](docs/GroupsObjectPermissionsApi.md#list) | **GET** {auth_group_href}object_permissions/ | List permissions
*PulpcoreClient::GroupsObjectPermissionsApi* | [**read**](docs/GroupsObjectPermissionsApi.md#read) | **GET** {auth_auth_groups_permission_href} | Inspect a permission
*PulpcoreClient::GroupsUsersApi* | [**create**](docs/GroupsUsersApi.md#create) | **POST** {auth_auth_groups_user_href}users/ | Create an user
*PulpcoreClient::GroupsUsersApi* | [**delete**](docs/GroupsUsersApi.md#delete) | **DELETE** {auth_auth_groups_user_href} | Delete an user
*PulpcoreClient::GroupsUsersApi* | [**list**](docs/GroupsUsersApi.md#list) | **GET** {auth_group_href}users/ | List users
*PulpcoreClient::ImportersCoreImportsApi* | [**create**](docs/ImportersCoreImportsApi.md#create) | **POST** {core_pulp_pulp_import_href}imports/ | Create a pulp import
*PulpcoreClient::ImportersCoreImportsApi* | [**delete**](docs/ImportersCoreImportsApi.md#delete) | **DELETE** {core_pulp_pulp_import_href} | Delete a pulp import
*PulpcoreClient::ImportersCoreImportsApi* | [**list**](docs/ImportersCoreImportsApi.md#list) | **GET** {pulp_importer_href}imports/ | List pulp imports
*PulpcoreClient::ImportersCoreImportsApi* | [**read**](docs/ImportersCoreImportsApi.md#read) | **GET** {core_pulp_pulp_import_href} | Inspect a pulp import
*PulpcoreClient::ImportersPulpApi* | [**create**](docs/ImportersPulpApi.md#create) | **POST** /pulp/api/v3/importers/core/pulp/ | Create a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**delete**](docs/ImportersPulpApi.md#delete) | **DELETE** {pulp_importer_href} | Delete a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**list**](docs/ImportersPulpApi.md#list) | **GET** /pulp/api/v3/importers/core/pulp/ | List pulp importers
*PulpcoreClient::ImportersPulpApi* | [**partial_update**](docs/ImportersPulpApi.md#partial_update) | **PATCH** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**read**](docs/ImportersPulpApi.md#read) | **GET** {pulp_importer_href} | Inspect a pulp importer
*PulpcoreClient::ImportersPulpApi* | [**update**](docs/ImportersPulpApi.md#update) | **PUT** {pulp_importer_href} | Update a pulp importer
*PulpcoreClient::OrphansApi* | [**delete**](docs/OrphansApi.md#delete) | **DELETE** /pulp/api/v3/orphans/ | Delete orphans
*PulpcoreClient::SigningServicesApi* | [**list**](docs/SigningServicesApi.md#list) | **GET** /pulp/api/v3/signing-services/ | List signing services
*PulpcoreClient::SigningServicesApi* | [**read**](docs/SigningServicesApi.md#read) | **GET** {signing_service_href} | Inspect a signing service
*PulpcoreClient::StatusApi* | [**status_read**](docs/StatusApi.md#status_read) | **GET** /pulp/api/v3/status/ | Inspect status of Pulp
*PulpcoreClient::TaskGroupsApi* | [**list**](docs/TaskGroupsApi.md#list) | **GET** /pulp/api/v3/task-groups/ | List task groups
*PulpcoreClient::TaskGroupsApi* | [**read**](docs/TaskGroupsApi.md#read) | **GET** {task_group_href} | Inspect a task group
*PulpcoreClient::TasksApi* | [**delete**](docs/TasksApi.md#delete) | **DELETE** {task_href} | Delete a task
*PulpcoreClient::TasksApi* | [**list**](docs/TasksApi.md#list) | **GET** /pulp/api/v3/tasks/ | List tasks
*PulpcoreClient::TasksApi* | [**read**](docs/TasksApi.md#read) | **GET** {task_href} | Inspect a task
*PulpcoreClient::TasksApi* | [**tasks_cancel**](docs/TasksApi.md#tasks_cancel) | **PATCH** {task_href} | Cancel a task
*PulpcoreClient::UploadsApi* | [**commit**](docs/UploadsApi.md#commit) | **POST** {upload_href}commit/ | Finish an Upload
*PulpcoreClient::UploadsApi* | [**create**](docs/UploadsApi.md#create) | **POST** /pulp/api/v3/uploads/ | Create an upload
*PulpcoreClient::UploadsApi* | [**delete**](docs/UploadsApi.md#delete) | **DELETE** {upload_href} | Delete an upload
*PulpcoreClient::UploadsApi* | [**list**](docs/UploadsApi.md#list) | **GET** /pulp/api/v3/uploads/ | List uploads
*PulpcoreClient::UploadsApi* | [**read**](docs/UploadsApi.md#read) | **GET** {upload_href} | Inspect an upload
*PulpcoreClient::UploadsApi* | [**update**](docs/UploadsApi.md#update) | **PUT** {upload_href} | Upload a file chunk
*PulpcoreClient::UsersApi* | [**list**](docs/UsersApi.md#list) | **GET** /pulp/api/v3/users/ | List users
*PulpcoreClient::UsersApi* | [**permissions**](docs/UsersApi.md#permissions) | **GET** {auth_user_href}permissions/ | 
*PulpcoreClient::UsersApi* | [**read**](docs/UsersApi.md#read) | **GET** {auth_user_href} | Inspect an user
*PulpcoreClient::WorkersApi* | [**list**](docs/WorkersApi.md#list) | **GET** /pulp/api/v3/workers/ | List workers
*PulpcoreClient::WorkersApi* | [**read**](docs/WorkersApi.md#read) | **GET** {worker_href} | Inspect a worker


## Documentation for Models

 - [PulpcoreClient::AccessPolicy](docs/AccessPolicy.md)
 - [PulpcoreClient::AccessPolicyResponse](docs/AccessPolicyResponse.md)
 - [PulpcoreClient::Artifact](docs/Artifact.md)
 - [PulpcoreClient::ArtifactResponse](docs/ArtifactResponse.md)
 - [PulpcoreClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpcoreClient::ContentAppStatusResponse](docs/ContentAppStatusResponse.md)
 - [PulpcoreClient::DatabaseConnectionResponse](docs/DatabaseConnectionResponse.md)
 - [PulpcoreClient::Group](docs/Group.md)
 - [PulpcoreClient::GroupProgressReportResponse](docs/GroupProgressReportResponse.md)
 - [PulpcoreClient::GroupResponse](docs/GroupResponse.md)
 - [PulpcoreClient::GroupUser](docs/GroupUser.md)
 - [PulpcoreClient::GroupUserResponse](docs/GroupUserResponse.md)
 - [PulpcoreClient::ImportResponse](docs/ImportResponse.md)
 - [PulpcoreClient::InlineResponse200](docs/InlineResponse200.md)
 - [PulpcoreClient::InlineResponse2001](docs/InlineResponse2001.md)
 - [PulpcoreClient::InlineResponse20010](docs/InlineResponse20010.md)
 - [PulpcoreClient::InlineResponse20011](docs/InlineResponse20011.md)
 - [PulpcoreClient::InlineResponse20012](docs/InlineResponse20012.md)
 - [PulpcoreClient::InlineResponse20013](docs/InlineResponse20013.md)
 - [PulpcoreClient::InlineResponse20014](docs/InlineResponse20014.md)
 - [PulpcoreClient::InlineResponse2002](docs/InlineResponse2002.md)
 - [PulpcoreClient::InlineResponse2003](docs/InlineResponse2003.md)
 - [PulpcoreClient::InlineResponse2004](docs/InlineResponse2004.md)
 - [PulpcoreClient::InlineResponse2005](docs/InlineResponse2005.md)
 - [PulpcoreClient::InlineResponse2006](docs/InlineResponse2006.md)
 - [PulpcoreClient::InlineResponse2007](docs/InlineResponse2007.md)
 - [PulpcoreClient::InlineResponse2008](docs/InlineResponse2008.md)
 - [PulpcoreClient::InlineResponse2009](docs/InlineResponse2009.md)
 - [PulpcoreClient::PatchedAccessPolicy](docs/PatchedAccessPolicy.md)
 - [PulpcoreClient::PatchedGroup](docs/PatchedGroup.md)
 - [PulpcoreClient::PatchedPulpExporter](docs/PatchedPulpExporter.md)
 - [PulpcoreClient::PatchedPulpImporter](docs/PatchedPulpImporter.md)
 - [PulpcoreClient::PatchedTaskCancel](docs/PatchedTaskCancel.md)
 - [PulpcoreClient::PermissionResponse](docs/PermissionResponse.md)
 - [PulpcoreClient::ProgressReportResponse](docs/ProgressReportResponse.md)
 - [PulpcoreClient::PulpExport](docs/PulpExport.md)
 - [PulpcoreClient::PulpExportResponse](docs/PulpExportResponse.md)
 - [PulpcoreClient::PulpExporter](docs/PulpExporter.md)
 - [PulpcoreClient::PulpExporterResponse](docs/PulpExporterResponse.md)
 - [PulpcoreClient::PulpImport](docs/PulpImport.md)
 - [PulpcoreClient::PulpImporter](docs/PulpImporter.md)
 - [PulpcoreClient::PulpImporterResponse](docs/PulpImporterResponse.md)
 - [PulpcoreClient::RedisConnectionResponse](docs/RedisConnectionResponse.md)
 - [PulpcoreClient::SigningServiceResponse](docs/SigningServiceResponse.md)
 - [PulpcoreClient::StatusResponse](docs/StatusResponse.md)
 - [PulpcoreClient::StorageResponse](docs/StorageResponse.md)
 - [PulpcoreClient::TaskGroupResponse](docs/TaskGroupResponse.md)
 - [PulpcoreClient::TaskResponse](docs/TaskResponse.md)
 - [PulpcoreClient::Upload](docs/Upload.md)
 - [PulpcoreClient::UploadChunk](docs/UploadChunk.md)
 - [PulpcoreClient::UploadChunkResponse](docs/UploadChunkResponse.md)
 - [PulpcoreClient::UploadCommit](docs/UploadCommit.md)
 - [PulpcoreClient::UploadDetailResponse](docs/UploadDetailResponse.md)
 - [PulpcoreClient::UploadResponse](docs/UploadResponse.md)
 - [PulpcoreClient::UserGroupResponse](docs/UserGroupResponse.md)
 - [PulpcoreClient::UserResponse](docs/UserResponse.md)
 - [PulpcoreClient::VersionResponse](docs/VersionResponse.md)
 - [PulpcoreClient::WorkerResponse](docs/WorkerResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

