# PulpcoreClient::AccessPoliciesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](AccessPoliciesApi.md#list) | **GET** /pulp/api/v3/access_policies/ | List access policys
[**partial_update**](AccessPoliciesApi.md#partial_update) | **PATCH** {access_policy_href} | Update an access policy
[**read**](AccessPoliciesApi.md#read) | **GET** {access_policy_href} | Inspect an access policy
[**update**](AccessPoliciesApi.md#update) | **PUT** {access_policy_href} | Update an access policy



## list

> InlineResponse200 list(opts)

List access policys

ViewSet for AccessPolicy.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: 'ordering_example', # String | Which field to use when ordering the results.
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #List access policys
  result = api_instance.list(opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | **String**| Which field to use when ordering the results. | [optional] 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**InlineResponse200**](InlineResponse200.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## partial_update

> AccessPolicyResponse partial_update(access_policy_href, patched_access_policy)

Update an access policy

ViewSet for AccessPolicy.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
access_policy_href = 'access_policy_href_example' # String | 
patched_access_policy = PulpcoreClient::PatchedAccessPolicy.new # PatchedAccessPolicy | 

begin
  #Update an access policy
  result = api_instance.partial_update(access_policy_href, patched_access_policy)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->partial_update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **access_policy_href** | **String**|  | 
 **patched_access_policy** | [**PatchedAccessPolicy**](PatchedAccessPolicy.md)|  | 

### Return type

[**AccessPolicyResponse**](AccessPolicyResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## read

> AccessPolicyResponse read(access_policy_href, opts)

Inspect an access policy

ViewSet for AccessPolicy.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
access_policy_href = 'access_policy_href_example' # String | 
opts = {
  fields: 'fields_example', # String | A list of fields to include in the response.
  exclude_fields: 'exclude_fields_example' # String | A list of fields to exclude from the response.
}

begin
  #Inspect an access policy
  result = api_instance.read(access_policy_href, opts)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **access_policy_href** | **String**|  | 
 **fields** | **String**| A list of fields to include in the response. | [optional] 
 **exclude_fields** | **String**| A list of fields to exclude from the response. | [optional] 

### Return type

[**AccessPolicyResponse**](AccessPolicyResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## update

> AccessPolicyResponse update(access_policy_href, access_policy)

Update an access policy

ViewSet for AccessPolicy.  NOTE: This API endpoint is in \"tech preview\" and subject to change

### Example

```ruby
# load the gem
require 'pulpcore_client'
# setup authorization
PulpcoreClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpcoreClient::AccessPoliciesApi.new
access_policy_href = 'access_policy_href_example' # String | 
access_policy = PulpcoreClient::AccessPolicy.new # AccessPolicy | 

begin
  #Update an access policy
  result = api_instance.update(access_policy_href, access_policy)
  p result
rescue PulpcoreClient::ApiError => e
  puts "Exception when calling AccessPoliciesApi->update: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **access_policy_href** | **String**|  | 
 **access_policy** | [**AccessPolicy**](AccessPolicy.md)|  | 

### Return type

[**AccessPolicyResponse**](AccessPolicyResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

